pub struct Plot<T: Data> { /* private fields */ }
The type of a plot widget.

See Plot::new for information on how to construct this.

This implements druid::Widget so it can be used like any other widget type.

fn build_plot_widget() -> impl Widget<()> {
    // ... construct and return widget using Plot::new()
}

let main_window = WindowDesc::new(build_plot_widget);

Implementations

Create a plot widget

This takes a function that should draw the plot using the normal plotters API. The function has access to the width and height of the plotting area, to the Data of the rust widget, and to a plotters DrawingArea.

Plot::new(|(width, height), data: &AppState, root| {
    root.fill(&WHITE).unwrap();
    let mut chart = ChartBuilder::on(&root)
        .build_cartesian_2d(-1f32..1f32, -0.1f32..1f32)
        .unwrap();

    // see the plotters documentation on how to use `chart`
});